@@ -29,7 +29,7 @@ static const unsigned long _glibtop_sysdeps_ppp = 0;
 /* Init function. */
 
 void
-glibtop_init_ppp_p (glibtop *server)
+_glibtop_init_ppp_p (glibtop *server)
 {
 	server->sysdeps.ppp = _glibtop_sysdeps_ppp;
 }
